bbprep.selectors.BySmartsSelector
=================================

.. currentmodule:: bbprep.selectors

.. autoclass:: BySmartsSelector
   :members:

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~BySmartsSelector.select_atoms
      ~BySmartsSelector.yield_stepwise
   
   

   
   
   